@@ -119,7 +119,7 @@ class FileUtils:
 
         return b_success, i_files_deleted
 
-    def get_all_files_or_directories_with_mask(self, s_mask):
+    def get_all_files_or_directories_with_mask(self, s_mask="*"):
         """
         Get all files matching a given mask or the directories.
         Example mask: '/proc/[0-9]*/' will return the directories that start from a number.
